package com.bonus.canteen.core.device.service;

import java.util.List;

import com.bonus.canteen.core.device.domain.ApkDTO;
import com.bonus.canteen.core.device.domain.DeviceAppVersion;
import com.bonus.common.core.web.domain.AjaxResult;

import javax.validation.Valid;

/**
 * 版本Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface IDeviceAppVersionService {
    /**
     * 查询版本
     * 
     * @param id 版本主键
     * @return 版本
     */
    public DeviceAppVersion selectDeviceAppVersionById(Integer id);

    /**
     * 查询版本列表
     * 
     * @param deviceAppVersion 版本
     * @return 版本集合
     */
    public List<DeviceAppVersion> selectDeviceAppVersionList(DeviceAppVersion deviceAppVersion);

    /**
     * 新增版本
     * 
     * @param deviceAppVersion 版本
     * @return 结果
     */
    public int insertDeviceAppVersion(DeviceAppVersion deviceAppVersion);

    /**
     * 修改版本
     * 
     * @param deviceAppVersion 版本
     * @return 结果
     */
    public int updateDeviceAppVersion(DeviceAppVersion deviceAppVersion);

    /**
     * 批量删除版本
     * 
     * @param ids 需要删除的版本主键集合
     * @return 结果
     */
    public int deleteDeviceAppVersionByIds(Integer[] ids);

    /**
     * 删除版本信息
     * 
     * @param id 版本主键
     * @return 结果
     */
    public int deleteDeviceAppVersionById(Integer id);

    /**
     * 上传apk
     * @param dto 入参
     * @return 结果
     */
    AjaxResult uploadApk(@Valid ApkDTO dto);
}
